@@ -1,20 +1,27 @@
 #!/usr/bin/env python3
 
-'''definition of class Draw'''
+"""Definition of class Draw."""
 
+from typing import Any
 import pygame as pg
 
-from . import Coord
+from . import types, Pos
 
 
 class Draw:
-    '''defines several drawing functions'''
+    """Class Draw provides several drawing functions."""
 
     BLACK = (0, 0, 0, 0)
 
     @classmethod
-    def rectangle(cls, surface, color, rect, width=0):
-        '''draw rectangle rect on the surface with the given color and width'''
+    def rectangle(
+            cls,
+            surface: pg.surface.Surface,
+            color: Any,
+            rect: Any,
+            width: int = 0
+    ) -> None:
+        """Draw a rectangle rect."""
         x, y, w, h = rect
         if w == 0 or h == 0:
             return
@@ -23,7 +30,8 @@ class Draw:
         else:
             if width > 2 * w or width > 2 * h:
                 msg = 'incorrect width for a ({}, {}) rectangle: {}'.format(
-                    w, h, width)
+                    w, h, width
+                )
                 raise ValueError(msg)
             pg.draw.rect(surface, color, (x, y, w, width))
             pg.draw.rect(surface, color, (x, y, width, h))
@@ -31,11 +39,17 @@ class Draw:
             pg.draw.rect(surface, color, (x, y + h - width, w, width))
 
     @classmethod
-    def rectangle_rounded(cls, surface, color,  # pylint: disable=R0913
-                          rect, radius, width=0):
-        '''draw a rounded rectangle with corners having the given radius'''
+    def rectangle_rounded(
+            cls,
+            surface: pg.surface.Surface,
+            color: Any,
+            rect: Any,
+            radius: int,
+            width: int = 0
+    ) -> None:  # pylint: disable=R0913
+        """Draw a rounded rectangle rect."""
 
-        def draw_sub_rects():
+        def draw_sub_rects() -> None:
             #  draw sub rectangles
             if width == 0 or width is None:
                 rects = [
@@ -53,23 +67,25 @@ class Draw:
             for r in rects:
                 Draw.rectangle(surface, color, r)
 
-        def draw_angles():
+        def draw_angles() -> None:
             #  draw rounded angles
             circle = pg.Surface((radius * 2, radius * 2)).convert_alpha()
             circle.fill(Draw.BLACK)
             pg.draw.circle(
-                circle, color, (radius, radius), radius)
+                circle, color, (radius, radius), radius
+            )
             if not (width == 0 or width is None):
                 pg.draw.circle(
-                    circle, Draw.BLACK, (radius, radius), radius - width)
+                    circle, Draw.BLACK, (radius, radius), radius - width
+                )
             cs = (radius, radius)
             for pos, area in [
-                    ((x, y), Coord.rect((0, 0), cs)),
-                    ((x + w - radius, y), Coord.rect((radius, 0), cs)),
-                    ((x, y + h - radius), Coord.rect((0, radius), cs)),
-                    ((x + w - radius, y + h - radius), Coord.rect(cs, cs))
+                    ((x, y), Pos.rect((0, 0), cs)),
+                    ((x + w - radius, y), Pos.rect((radius, 0), cs)),
+                    ((x, y + h - radius), Pos.rect((0, radius), cs)),
+                    ((x + w - radius, y + h - radius), Pos.rect(cs, cs))
             ]:
-                surface.blit(circle, pos, area=area)
+                surface.blit(circle, pos, area=pg.Rect(area))
 
         x, y, w, h = rect
         radius = min(radius, int(w / 2), int(h / 2))
@@ -83,9 +99,15 @@ class Draw:
         draw_angles()
 
     @classmethod
-    def circle(cls, surface, color,  # pylint: disable=R0913
-               origin, radius, width=0):
-        '''draw a circle'''
+    def circle(
+            cls,
+            surface: pg.surface.Surface,
+            color: Any,
+            origin: types.pos_t,
+            radius: int,
+            width: int = 0
+    ) -> None:  # pylint: disable=R0913
+        """Draw a circle."""
         if width == 0:
             pg.draw.circle(surface, color, origin, radius)
         else:
