@@ -1,12 +1,12 @@
 #!/usr/bin/env python3
 
-'''definition of class event'''
+"""Definition of class event."""
 
 from . import EnumType
 
 
 class Event(metaclass=EnumType):  # pylint: disable=R0903
-    '''enumerate all possible event types'''
+    """Class Event enumerates all handled event types."""
 
     #  the node has been activated
     ON_ACTIVATE = 'on-activate'
@@ -14,9 +14,11 @@ class Event(metaclass=EnumType):  # pylint: disable=R0903
     #  the value of the node has changed
     ON_CHANGE = 'on-change'
 
-    #  the mouse left button is being pressed while the cursor is on
-    #  the node
-    ON_CLICK = 'on-click'
+    #  the node get the clicked status
+    ON_CLICKED = 'on-clicked'
+
+    #  left-click up on the node
+    ON_CLICKUP = 'on-click-up'
 
     #  left-click down on the node
     ON_CLICKDOWN = 'on-click-down'
@@ -24,12 +26,12 @@ class Event(metaclass=EnumType):  # pylint: disable=R0903
     #  right-click down on the node
     ON_CLICKDOWNRIGHT = 'on-click-down-right'
 
-    #  left-click up on the node
-    ON_CLICKUP = 'on-click-up'
-
     #  right-click up on the node
     ON_CLICKUPRIGHT = 'on-click-up-right'
 
+    #  the node window is closed
+    ON_CLOSE = 'on-close'
+
     #  the node has been disabled
     ON_DISABLE = 'on-disable'
 
@@ -39,19 +41,22 @@ class Event(metaclass=EnumType):  # pylint: disable=R0903
     #  the node received the focus
     ON_FOCUS = 'on-focus'
 
-    #  a key has been pressed while the node has the focus
+    #  a key has been pressed
     ON_KEY = 'on-key'
 
     #  the mouse wheel has been used over the node
     ON_MOUSEWHEEL = 'on-mouse-wheel'
 
+    #  the node window is opened
+    ON_OPEN = 'on-open'
+
     #  the cursor just moved over the node
     ON_OVER = 'on-over'
 
-    #  the cursor was previously on the node and is still over it
+    #  the cursor was previously on the node, and is still over it
     ON_OVERAGAIN = 'on-over-again'
 
-    #  the node is a menu item that has been selected
+    #  the node has been selected
     ON_SELECT = 'on-select'
 
     #  the node has lost the focus
@@ -60,5 +65,8 @@ class Event(metaclass=EnumType):  # pylint: disable=R0903
     #  the cursor is not over the node anymore
     ON_UNOVER = 'on-unover'
 
-    #  the node is a menu item that has been unselected
+    #  the node has been unselected
     ON_UNSELECT = 'on-unselect'
+
+    #  the node get the unclicked status
+    ON_UNCLICKED = 'on-unclicked'
